@@ -79,16 +79,10 @@ const BooleanInput = ({
 const StyledBooleanInput = styled(BooleanInput)`
   h4 {
     padding: 0 0 5px 0;
-    font-size: 12px;
-    font-weight: bold;
-    text-transform: uppercase;
-    color: black;
   }
 
   p {
     padding: 0 0 10px 0;
-    font-size: 13px;
-    color: #333;
   }
 
   label {
@@ -109,10 +103,9 @@ const StyledBooleanInput = styled(BooleanInput)`
     letter-spacing: 0.05em;
     line-height: 1em;
 
-    color: black;
-    background-color: #f3f3f3;
-    border: 0;
-    border: 1px solid transparent;
+    color: #212529;
+    background-color: #f8f9fa;
+    border: 1px solid rgba(0, 0, 0, 0.125);
     border-radius: 4px;
     outline: none;
 
@@ -134,7 +127,8 @@ const StyledBooleanInput = styled(BooleanInput)`
   }
 
   label span:hover {
-    border: 1px solid #005c75;
+    border-color: #005c75;
+    box-shadow: 0 0 0 0.25rem rgb(13 110 253 / 25%);
   }
 
   input:checked + span {
