@@ -2,10 +2,10 @@ import React, { useEffect, useState } from 'react';
 import styled from 'styled-components';
 import { Link } from 'react-router-dom';
 import { requestAPI } from '../../handler';
-import { Workflow } from './schema';
-import { faFolderOpen } from '@fortawesome/free-solid-svg-icons';
+import { Workflow } from './types';
+import StyledEmptyPanel from '../common/EmptyPanel';
 import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
-
+import { faDna, faFolderOpen } from '@fortawesome/free-solid-svg-icons';
 
 // -----------------------------------------------------------------------------
 // Component
@@ -25,7 +25,7 @@ const WorkflowsList = ({ className }: IWorkflowsList): JSX.Element => {
   // ------------------------------------
   const getWorkflows = async () => {
     const wfs = await requestAPI<any>('workflows');
-    setWorkflows(Object.values(wfs))
+    setWorkflows(Object.values(wfs));
   };
 
   useEffect(() => {
@@ -34,15 +34,10 @@ const WorkflowsList = ({ className }: IWorkflowsList): JSX.Element => {
 
   if (workflows.length === 0) {
     return (
-      <div className={`workflows-list empty ${className}`}>
-        <div className="empty">
-          <h2>
-            <FontAwesomeIcon icon={faFolderOpen} />
-            No workflows installed.
-          </h2>
-        </div>
+      <div className={`workflows-list ${className}`}>
+        <StyledEmptyPanel body="No workflows installed" icon={faFolderOpen} />
       </div>
-    )
+    );
   }
 
   return (
@@ -51,67 +46,50 @@ const WorkflowsList = ({ className }: IWorkflowsList): JSX.Element => {
         {workflows.map((Item: Workflow) => (
           <li>
             <div className="workflow">
-              <div>
+              <Link className="workflow-link" to={`/workflows/${Item.name}`}>
                 <div className="workflow-header">
-                  <span>Version {Item.defaults.wfversion}</span>
-                  <h3>{Item.name}</h3>
+                  <FontAwesomeIcon icon={faDna} />
                 </div>
-                <div className="workflow-buttons">
-                  <a className="workflow-url" href={Item.url}>
-                    Github
-                  </a>
-                  <Link
-                    className="workflow-link"
-                    to={`/workflows/${Item.name}`}
-                  >
-                    <div>Open workflow</div>
-                  </Link>
+                <div className="workflow-details">
+                  <div className="workflow-name">
+                    <p className="preheader">Workflow name</p>
+                    <h3 className="large">{Item.name}</h3>
+                  </div>
+                  <div className="workflow-version">
+                    <p className="preheader">Workflow version</p>
+                    <h4>{Item.defaults.wfversion}</h4>
+                  </div>
                 </div>
-              </div>
+              </Link>
             </div>
           </li>
         ))}
       </ul>
     </div>
-  )
+  );
 };
 
 // -----------------------------------------------------------------------------
 // Component Styles
 // -----------------------------------------------------------------------------
 const StyledWorkflowsList = styled(WorkflowsList)`
-  max-width: 1200px;
-  margin: 50px auto 0 auto;
+  && {
+    max-width: calc(1024px + 30px);
+    padding: 0 15px 15px 15px;
+    margin: 0 auto;
+    box-sizing: border-box;
+  }
 
   > ul {
     display: grid;
-    grid-template-columns: repeat(auto-fit, minmax(500px, 1fr));
+    grid-template-columns: repeat(auto-fit, minmax(300px, 1fr));
     grid-template-rows: minmax(min-content, max-content);
     grid-column-gap: 20px;
     grid-row-gap: 20px;
     list-style: none;
   }
 
-  .empty {
-    width: 100%;
-    height: 250px;
-    display: flex;
-    align-items: center;
-    justify-content: center;
-    background-color: white;
-    box-shadow: 0 6px 15px rgb(36 37 38 / 8%);
-    border-radius: 4px;
-    transition: box-shadow 0.25s ease, transform 0.25s ease;
-    background-color: #ffffff;
-  }
-
-  .empty svg {
-    padding-right: 15px;
-    color: lightgray;
-  }
-
   .workflow {
-    padding: 15px;
     display: flex;
     flex-direction: column;
     justify-content: space-between;
@@ -120,50 +98,45 @@ const StyledWorkflowsList = styled(WorkflowsList)`
     border-radius: 4px;
     transition: box-shadow 0.25s ease, transform 0.25s ease;
   }
-  h3 {
-    font-size: 24px;
-  }
 
-  .workflow span {
-    color: #333;
-  }
-
-  .workflow-header span {
-    letter-spacing: 0.05em;
-    color: #a0a0a0;
-    text-transform: uppercase;
-    font-size: 11px;
-    line-height: 1em;
-    padding-bottom: 5px;
-  }
   .workflow-header {
+    box-sizing: border-box;
+    width: 100%;
+    padding: 25px 25px 0;
     display: flex;
-    justify-content: space-between;
-    flex-direction: column-reverse;
-  }
-  .workflow-buttons {
-    display: flex;
-    justify-content: space-between;
-    align-items: flex-end;
-  }
-  .workflow-link {
-    color: #1d9655;
-  }
-  .workflow-buttons div {
-    padding: 15px 25px;
-    border: 1px solid #1d9655;
-    color: #1d9655;
-    text-transform: uppercase;
-    font-size: 11px;
+    align-items: center;
+    justify-content: flex-start;
     border-radius: 4px;
-    font-weight: bold;
-    line-height: 1em;
-    letter-spacing: 0.05em;
-    transition: 0.2s ease-in-out all;
+    border-bottom-left-radius: 0;
+    border-bottom-right-radius: 0;
   }
-  .workflow-buttons div:hover {
-    background-color: #1d9655;
-    color: white;
+
+  .workflow-header svg {
+    padding: 15px 16px;
+    border-radius: 50px;
+    background-color: transparent;
+    border: 2px solid #00485b;
+    color: #00485b;
+  }
+
+  .workflow-details {
+    padding: 25px 25px 25px 25px;
+    text-align: left;
+  }
+
+  .workflow-details p {
+    padding: 0 0 5px 0;
+    color: #ccc;
+  }
+
+  .workflow-name {
+    padding: 0 0 10px 0;
+    margin: 0 0 15px 0;
+    text-align: left;
+    display: flex;
+    flex-direction: column;
+    justify-content: space-between;
+    border-bottom: 1px solid #f2f2f2;
   }
 `;
 
